@@ -128,7 +128,7 @@ module distrib
      subroutine Ed2llkdist_generic(argsD, m, n, mu, nu, skip, E)
        !**********************************************************************
        !  Ed2llk_dist calculates
-       !           E(dl2/dmu2), E(dl2/dmUdnu) and E(dl2/dnu2)
+       !           -E(dl2/dmu2), -E(dl2/dmUdnu) and -E(dl2/dnu2)
        !  the exepcted values of the second derivatives of the log-likelihood
        !**********************************************************************
        ! Input
@@ -344,7 +344,7 @@ contains
   subroutine Ed2llk_beta(argsD, m, n, mu, nu, skip, E)
     !**********************************************************************
     !  Computes
-    !          E(dl2/dmu2), E(dl2/dmUdnu) and E(dl2/dnu2)
+    !          -E(dl2/dmu2), -E(dl2/dmUdnu) and -E(dl2/dnu2)
     !  for beta regression models
     !**********************************************************************
     implicit none
@@ -568,7 +568,7 @@ contains
   subroutine Ed2llk_kuma(argsD, m, n, mu, nu, skip, E)
     !**********************************************************************
     !  Computes
-    !       E(dl2/dmu2), E(dl2/dmUdnu) and E(dl2/dnu2)
+    !       -E(dl2/dmu2), -E(dl2/dmUdnu) and -E(dl2/dnu2)
     !  for Kumaraswamy regression models
     !**********************************************************************
     implicit none
@@ -743,7 +743,7 @@ contains
   subroutine Ed2llk_gamma(argsD, m, n, mu, nu, skip, E)
     !**********************************************************************
     !  Computes
-    !      E(dl2/dmu2), E(dl2/dmUdnu) and E(dl2/dnu2)
+    !      -E(dl2/dmu2), -E(dl2/dmUdnu) and -E(dl2/dnu2)
     !  for gamma regression models
     !**********************************************************************
     implicit none
@@ -908,8 +908,11 @@ contains
   subroutine Ed2llk_uw(argsD, m, n, mu, nu, skip, E)
     !**********************************************************************
     !  Computes
-    !      E(dl2/dmu2), E(dl2/dmUdnu) and E(dl2/dnu2)
+    !      -E(dl2/dmu2), -E(dl2/dmUdnu) and -E(dl2/dnu2)
     !  for Unit-Weibull regression models.
+		!
+		! Last update: January/2026.
+		!  - corrected the constant "cons2"
     !**********************************************************************
     implicit none
     class(argsDist), intent(inout) :: argsD
@@ -926,7 +929,7 @@ contains
     lr = log(-log(argsD%par))
     cons0 = em + lr
     cons1 = cons0 - 1
-    cons2 = lr * (lr + 2 * em - 2) + pi**2 / 6 + (em - 2) * em
+    cons2 = lr * (lr + 2 * em - 2) - pi**2 * (em - 2) * em / 6
 
     do t = (m + 1), n
        if (skip(1) == 0) E(t, 1) = (nu(t) / (mu(t) * log(mu(t))))**2
@@ -1049,7 +1052,7 @@ contains
   subroutine Ed2llk_matsu(argsD, m, n, mu, nu, skip, E)
     !**********************************************************************
     !   Computes
-    !      E(dl2/dmu2), E(dl2/dmUdnu) and E(dl2/dnu2)
+    !      -E(dl2/dmu2), -E(dl2/dmUdnu) and -E(dl2/dnu2)
     !   for Matsuoka regression models.
     !**********************************************************************
     implicit none
@@ -1186,8 +1189,11 @@ contains
   subroutine Ed2llk_ul(argsD, m, n, mu, nu, skip, E)
     !--------------------------------------------------------
     !   Computes
-    !        E(dl2/dmu2), E(dl2/dmUdnu) and E(dl2/dnu2)
+    !        -E(dl2/dmu2), -E(dl2/dmUdnu) and -E(dl2/dnu2)
     !   for Unit Lindley regression models.
+		!
+		! Last update: january/2026
+		!   - corrected the signal of the expected value
     !--------------------------------------------------------
     implicit none
     class(argsDist), intent(inout) :: argsD
@@ -1203,7 +1209,7 @@ contains
 
     do t = (m + 1), n
        m1 = (1.d0 - mu(t))**2
-       E(t, 1) = (m1 - 2.d0) / mu(t)**2
+       E(t, 1) = (2.d0 - m1) / mu(t)**2
        E(t, 1) = E(t, 1) / m1
     end do
     return
